( cd usr/lib ; rm -rf libautotrace.so.3 )
( cd usr/lib ; ln -sf libautotrace.so.3.0.0 libautotrace.so.3 )
( cd usr/lib ; rm -rf libautotrace.so )
( cd usr/lib ; ln -sf libautotrace.so.3.0.0 libautotrace.so )
